# cjm-pandas-utils

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This file will become your README and also the index of your
documentation.

## Install

``` sh
pip install cjm_pandas_utils
```

## How to use

### markdown_to_pandas

``` python
from cjm_pandas_utils.core import markdown_to_pandas
```

``` python
md_table_str = """
| Name | Age | Occupation |
| ---- | --- | ---------- |
| John | 35  | Engineer    |
| Jane | 29  | Teacher     |
| Bob  | 42  | Doctor      |
"""
```

``` python
markdown_df = markdown_to_pandas(md_table_str)
markdown_df.iloc[1]
```

    Name             Jane
    Age                29
    Occupation    Teacher
    Name: 1, dtype: object
